=======
History
=======

0.2.0 (2019-06-28)
------------------

* Update for Creoson 2.4.0 release. New functions:
    * parameter_set_designated
    * feature_list_group_features
    * feature_list_pattern_features
* Add missing function: 
    * feature_list_params


0.1.0 (2019-06-22)
------------------

* First release on PyPI.
